@@ -56,13 +56,13 @@ framework_dir <- function(y, smp_data, smp_domains, weights,
   if (is.null(threshold)) {
     if (is.null(weights)) {
       threshold <- 0.6 * median(y_vec)
-      cat("The threshold for the HCR and the PG is automatically set to 60% of 
+      message("The threshold for the HCR and the PG is automatically set to 60% of 
         the median of the dependent variable and equals",threshold, "\n")
     } else if (!is.null(weights)) {
       threshold <- 0.6 * wtd.quantile(x = y_vec, 
                                      weights = weights_vec,
                                      probs = .5)
-      cat("The threshold for the HCR and the PG is automatically set to 60% of 
+      message("The threshold for the HCR and the PG is automatically set to 60% of 
         the weighted median of the dependent variable and equals",threshold, "\n")
     }
   }
